# concrete-hnumpy

Our mission at [Zama](https://zama.ai) is to protect people’s privacy by preventing data breaches and unethical surveillance.

Following a recent breakthrough in homomorphic encryption, we are now building a ZeroTrust deep learning framework that enables fast and accurate inference over encrypted data, with minimal performance overhead, no changes to the network architecture and no retraining necessary.

[Zama](https://zama.ai) is open-source by design, as we believe privacy-enabling technologies should benefit the widest possible community of developers and researchers.

# Warning

This package is not a working package.

# Test

```python

import concrete-hnumpy
concrete-hnumpy.hello_world()
```
